@@ -7,7 +7,7 @@ from . import utils as djsciops_utils
 
 
 def _generate_transfer_mapping(
-    session, s3_bucket: str, source: Union(str, list), destination: Union(str, list)
+    session, s3_bucket: str, source: Union[str, list], destination: Union[str, list]
 ) -> tuple:
     if (
         isinstance(source, list)
